@@ -40,6 +40,8 @@ def _add_markers(config):
     config.addinivalue_line("markers", "qase_author: mark test with author")
     config.addinivalue_line("markers", "qase_fields: mark test with meta data")
     config.addinivalue_line("markers", "qase_suite: mark test with suite")
+    config.addinivalue_line(
+        "markers", "qase_ignore_parameters: mark test to ignore specific parameters in Qase reports")
 
     # Legacy markers | These markers are deprecated and will be removed in future versions
     config.addinivalue_line(
@@ -184,6 +186,22 @@ def setup_config_manager(config):
                 config_manager.config.testops.configurations.set_create_if_not_exists(
                     config.option.__dict__[option])
 
+            if option == "qase_testops_status_filter" and config.option.__dict__[option] is not None:
+                config_manager.config.testops.set_status_filter(
+                    [status.strip() for status in config.option.__dict__[option].split(',')])
+
+            if option == "qase_testops_run_external_link_type" and config.option.__dict__[option] is not None:
+                if not config_manager.config.testops.run.external_link:
+                    from qase.commons.models.external_link import ExternalLinkConfig
+                    config_manager.config.testops.run.external_link = ExternalLinkConfig()
+                config_manager.config.testops.run.external_link.set_type(config.option.__dict__[option])
+
+            if option == "qase_testops_run_external_link_url" and config.option.__dict__[option] is not None:
+                if not config_manager.config.testops.run.external_link:
+                    from qase.commons.models.external_link import ExternalLinkConfig
+                    config_manager.config.testops.run.external_link = ExternalLinkConfig()
+                config_manager.config.testops.run.external_link.set_link(config.option.__dict__[option])
+
     return config_manager
 
 
